@@ -5,7 +5,7 @@
 {
     distname <- deparse(substitute(distfun))
     distfun <- match.fun(distfun)
-    zerodist <- match.arg(zerodist, c("fail", "add"))
+    zerodist <- match.arg(zerodist, c("fail", "add", "ignore"))
     formals(distfun) <- c(formals(distfun), alist(... = ))
     formals(stepacross) <- c(formals(stepacross), alist(... = ))
     if (missing(commname)) 
