@@ -39,7 +39,8 @@
             }
             E <- sweep(E, 2, c(object$pCCA$envcentre, object$CCA$envcentre), 
                        "-")
-            p1 <- object[[model]]$QR$pivot[1:object[[model]]$rank]
+            Q <- object[[model]]$QR
+            p1 <- Q$pivot[1:Q$rank]
             u <- E[, p1, drop = FALSE] %*% coef(object)[p1, , 
                          drop = FALSE]
             u <- u[, 1:take, drop = FALSE]
