@@ -2,10 +2,11 @@
     function (x, digits = max(3, getOption("digits") - 3), ...) 
 {
     if (inherits(x, "pcaiv")) {
-        stop("this is an ade4 object which vegan cannot handle")
+        warning("this is an ade4 object which vegan cannot handle")
+        x <- ade2vegancca(x)
     }
-    cat("\nCall:\n")
-    cat(deparse(x$call), "\n\n")
+    writeLines(strwrap(pasteCall(x$call)))
+    cat("\n")
     chi <- rbind(x$tot.chi, x$pCCA$tot.chi, x$CCA$tot.chi, x$CA$tot.chi)
     rnk <- rbind(NA, x$pCCA$rank, x$CCA$rank, x$CA$rank)
     tbl <- cbind(chi, rnk)
