@@ -4,7 +4,11 @@
     cat("\nPermutation test for", x$method, "\nCall:\n")
     cat(deparse(x$call), "\n\n")
     Pval <- sum(x$F.perm >= x$F.0)/x$nperm
-    cat("Test for significance of all constrained eigenvalues\n")
+    cat("Permutation test for ")
+    if (x$first)
+        cat("first constrained eigenvalue\n")
+    else
+        cat("all constrained eigenvalues\n")
     cat("Pseudo-F:\t", x$F.0, "\n")
     cat("Significance:\t", format.pval(Pval, eps = 1/x$nperm), 
         "\n")
