@@ -1,27 +1,23 @@
-"scores.cca" <-
+`scores.cca` <-
     function (x, choices = c(1, 2), display = c("sp", "wa", "cn"), 
               scaling = 2, ...) 
 {
+    if(inherits(x, "pcaiv")) {
+        warning("looks like ade4::cca object: you better use ade4 functions")
+        x <- ade2vegancca(x)
+    }
     tabula <- c("species", "sites", "constraints", "biplot", 
                 "centroids")
     names(tabula) <- c("sp", "wa", "lc", "bp", "cn")
     if (is.null(x$CCA)) 
         tabula <- tabula[1:2]
-    #if (length(display) == 1) {
-    #    display <- match.arg(display, c("sites", "species", "wa", 
-    #                                    "lc", "bp", "cn"))
-    #    if (display == "sites") 
-    #        display <- "wa"
-    #    else if (display == "species") 
-    #        display <- "sp"
-    #}
     display <- match.arg(display, c("sites", "species", "wa",
                                     "lc", "bp", "cn"),
                          several.ok = TRUE)
     if("sites" %in% display)
-      display[display == "sites"] <- "wa"
+        display[display == "sites"] <- "wa"
     if("species" %in% display)
-      display[display == "species"] <- "sp"
+        display[display == "species"] <- "sp"
     take <- tabula[display]
     slam <- sqrt(c(x$CCA$eig, x$CA$eig)[choices])
     rnk <- x$CCA$rank
